@@ -129,7 +129,7 @@ QIODevice *LocalLogFileReader::open()
         emit errorOccured(i18n("File Does Not Exist"), message);
         emit statusBarChanged(message);
         delete file;
-        return NULL;
+        return nullptr;
     }
 
     // Plain text file : we use a QFile object
@@ -145,11 +145,11 @@ QIODevice *LocalLogFileReader::open()
         // inputDevice = KFilterDev::deviceForFile(filePath, mimeType);
         inputDevice = new KCompressionDevice(filePath, KFilterDev::compressionTypeForMimeType(mimeType));
 
-        if (inputDevice == NULL) {
+        if (inputDevice == nullptr) {
             QString message(i18n("Unable to uncompress the '%2' format of '%1'.", filePath, mimeType));
             emit errorOccured(i18n("Unable to Uncompress File"), message);
             emit statusBarChanged(message);
-            return NULL;
+            return nullptr;
         }
     }
 
@@ -204,7 +204,7 @@ void LocalLogFileReader::logFileModified()
     }
 
     QIODevice *inputDevice = open();
-    if (inputDevice == NULL) {
+    if (inputDevice == nullptr) {
         logCritical() << "Could not open file " << d->logFile.url().path();
         return;
     }
